==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NsRecordArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NsRecordArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * An NS record.
 * @property nsdname The name server name for this NS record.
 */
public data class NsRecordArgs(
    public val nsdname: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.NsRecordArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.NsRecordArgs =
        com.pulumi.azurenative.network.inputs.NsRecordArgs.builder()
            .nsdname(nsdname?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NsRecordArgs].
 */
@PulumiTagMarker
public class NsRecordArgsBuilder internal constructor() {
    private var nsdname: Output<String>? = null

    /**
     * @param value The name server name for this NS record.
     */
    @JvmName("cfxwylpjtblisnsx")
    public suspend fun nsdname(`value`: Output<String>) {
        this.nsdname = value
    }

    /**
     * @param value The name server name for this NS record.
     */
    @JvmName("eywdytigvjyejxsr")
    public suspend fun nsdname(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nsdname = mapped
    }

    internal fun build(): NsRecordArgs = NsRecordArgs(
        nsdname = nsdname,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NsRecordArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NsRecordArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * An NS record.
 * @property nsdname The name server name for this NS record.
 */
public data class NsRecordArgs(
    public val nsdname: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.NsRecordArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.NsRecordArgs =
        com.pulumi.azurenative.network.inputs.NsRecordArgs.builder()
            .nsdname(nsdname?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NsRecordArgs].
 */
@PulumiTagMarker
public class NsRecordArgsBuilder internal constructor() {
    private var nsdname: Output<String>? = null

    /**
     * @param value The name server name for this NS record.
     */
    @JvmName("wlqrshlltpbhgpdw")
    public suspend fun nsdname(`value`: Output<String>) {
        this.nsdname = value
    }

    /**
     * @param value The name server name for this NS record.
     */
    @JvmName("mgrtcivlcbbqrpkp")
    public suspend fun nsdname(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nsdname = mapped
    }

    internal fun build(): NsRecordArgs = NsRecordArgs(
        nsdname = nsdname,
    )
}
